@@ -4,7 +4,7 @@ package App::ZofCMS::Template;
 use strict;
 use warnings;
 
-our $VERSION = '1.001001'; # VERSION
+our $VERSION = '1.001002'; # VERSION
 
 use HTML::Template;
 
@@ -97,6 +97,7 @@ sub assemble {
 
     my $template = $self->template;
     my $conf = $self->conf;
+    my $query = $self->query;
 
     my $html_template = HTML::Template->new(
         filename => File::Spec->catfile(
@@ -308,13 +309,10 @@ sub unique_plug_keys {
 }
 
 1;
-
 __END__
 
 =encoding utf8
 
-=for stopwords ModuleName foo perlish pm subref tmpl
-
 =head1 NAME
 
 App::ZofCMS::Template - "core" part of ZofCMS - web-framework/templating system
@@ -356,8 +354,8 @@ see the following:
 
 =head1 DESCRIPTION
 
-This module is used internally by L<App::ZofCMS> and this documentation
-explains how ZofCMS templates work. B<This documentation assumes you have
+This module is used internally by L<App::ZofCMS> and this documeantation
+explains how ZofCMS templates work. B<This documeantation assumes you have
 read> L<App::ZofCMS::Config>.
 
 If you wish to make changes to this module, please contact the author.
@@ -392,7 +390,7 @@ are called.
 There are (currently) four special "first level" keys in ZofCMS template
 hashref. They will NOT be stuffed into <tmpl_var>s in the base template.
 Some plugins may take their input via "first level" keys, make sure to
-read the documentation for any plugins you are using.
+read the documeantation for any plugins you are using.
 
 =head2 C<t>
 
@@ -440,10 +438,10 @@ hashref).
 Special key C<plugins> takes an B<arrayref> as a value. Can be postfixed by a number to
 create several levels of plugin sets to run (allows to execute same plugins several times).
 The higher the number the later that plugin set will execute.
-Elements of this
-arrayref can be either scalars or hashrefs. If the element is a scalar
+Elemeants of this
+arrayref can be either scalars or hashrefs. If the elemeant is a scalar
 it will be treated as the name of the plugin to load/execute; in this
-case the "priority" of the plugin is set to 10000. If the element is a
+case the "priority" of the plugin is set to 10000. If the elemeant is a
 hashref, the key of that hashref will be treated as the name of the
 plugin to load and the value will be treated as the value for plugin's
 "priority".
@@ -485,7 +483,7 @@ is a hashref keys of which are also special.
     conf => { base => 'base.tmpl', }
 
 The C<base> key in C<conf> hashref specifies the "base" template to use.
-This is the "base" template mentioned above in the description of
+This is the "base" template meantioned above in the description of
 "first level" keys of ZofCMS template hashref.
 The value of C<base> key must be a scalar containing a filename of the
 L<HTML::Template> located in "data store" directory. Normally, this would
@@ -554,7 +552,7 @@ its C<@_> (in that order):
 
 If the value of C<exec_before> is a scalar with the name of the module,
 the C<@_> of C<sub execute {}> will look the same except the first
-element will be $self (i.e. the object)
+elemeant will be $self (i.e. the object)
 
 The return value of C<exec_before> code is disregarded.
 
@@ -584,7 +582,7 @@ from the very beginning. Possibility here is changing query parameters.
 
 =head1 NOTE ON C<exec_before> AND C<exec> keys
 
-They were implemented before the plugin system was in place. Currently
+They were implemeanted before the plugin system was in place. Currently
 I find little use for either of them. They will stay as possibilities
 in ZofCMS but I encourage you to write plugins instead.
 
@@ -612,5 +610,4 @@ You can use and distribute this module under the same terms as Perl itself.
 See the C<LICENSE> file included in this distribution for complete
 details.
 
-=cut
-
+=cut
\ No newline at end of file
